// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

/// Tests for user defined Scalar functions
mod user_defined_scalar_functions;

/// Tests for User Defined Aggregate Functions
mod user_defined_aggregates;

/// Tests for User Defined Plans
mod user_defined_plan;

/// Tests for User Defined Window Functions
mod user_defined_window_functions;

/// Tests for User Defined Table Functions
mod user_defined_table_functions;

/// Tests for Expression Planner
mod expr_planner;

/// Tests for insert operations
mod insert_operation;
